Class: Prosody::DynamicResult

Inherits:
Object
  • Object
show all
Defined in:
lib/prosody/native_stubs.rb

Overview

Wrapper for dynamically-typed results returned from async operations. This is an internal class used by the native code to transfer results between Rust and Ruby.

Instance Method Summary collapse

Constructor Details

#initializeDynamicResult

Returns a new instance of DynamicResult.

Raises:

  • (NotImplementedError)


23
24
25
# File 'lib/prosody/native_stubs.rb', line 23

def initialize
  raise NotImplementedError, "This class is implemented natively in Rust"
end