Class: Prosody::Timer

Inherits:
Object
  • Object
show all
Defined in:
lib/prosody/native_stubs.rb,
sig/prosody.rbs

Overview

Represents a timer that was scheduled to fire at a specific time. Timer instances are passed to EventHandler's on_timer method when timers fire.

Instance Method Summary collapse

Constructor Details

#initializeTimer

Returns a new instance of Timer.

Parameters:

  • (Object)

Raises:

  • (NotImplementedError)


344
345
346
# File 'lib/prosody/native_stubs.rb', line 344

def initialize
  raise NotImplementedError, "This class is implemented natively in Rust"
end

Instance Method Details

#keyString

Returns the entity key identifying what this timer belongs to.

Returns:

  • (String)

    The entity key



354
355
356
# File 'lib/prosody/native_stubs.rb', line 354

def key
  raise NotImplementedError, "This method is implemented natively in Rust"
end

#timeTime

Returns the time when this timer was scheduled to fire.

Returns:

  • (Time)

    The scheduled execution time



365
366
367
# File 'lib/prosody/native_stubs.rb', line 365

def time
  raise NotImplementedError, "This method is implemented natively in Rust"
end