Class: Prosody::DynamicResult
- Inherits:
-
Object
- Object
- Prosody::DynamicResult
- Defined in:
- lib/prosody/native_stubs.rb
Overview
Wrapper for dynamically-typed results returned from async operations. This is an internal class used by the native code to transfer results between Rust and Ruby.
Instance Method Summary collapse
-
#initialize ⇒ DynamicResult
constructor
A new instance of DynamicResult.
Constructor Details
#initialize ⇒ DynamicResult
Returns a new instance of DynamicResult.
23 24 25 |
# File 'lib/prosody/native_stubs.rb', line 23 def initialize raise NotImplementedError, "This class is implemented natively in Rust" end |