Class: Prosody::Timer
- Inherits:
-
Object
- Object
- Prosody::Timer
- Defined in:
- lib/prosody/native_stubs.rb,
sig/prosody.rbs
Overview
Represents a timer that was scheduled to fire at a specific time. Timer instances are passed to EventHandler's on_timer method when timers fire.
Instance Method Summary collapse
-
#initialize ⇒ Timer
constructor
A new instance of Timer.
-
#key ⇒ String
Returns the entity key identifying what this timer belongs to.
-
#time ⇒ Time
Returns the time when this timer was scheduled to fire.
Constructor Details
#initialize ⇒ Timer
Returns a new instance of Timer.
344 345 346 |
# File 'lib/prosody/native_stubs.rb', line 344 def initialize raise NotImplementedError, "This class is implemented natively in Rust" end |
Instance Method Details
#key ⇒ String
Returns the entity key identifying what this timer belongs to.
354 355 356 |
# File 'lib/prosody/native_stubs.rb', line 354 def key raise NotImplementedError, "This method is implemented natively in Rust" end |
#time ⇒ Time
Returns the time when this timer was scheduled to fire.
365 366 367 |
# File 'lib/prosody/native_stubs.rb', line 365 def time raise NotImplementedError, "This method is implemented natively in Rust" end |